summaryrefslogtreecommitdiffstats
path: root/kommander/editor/formwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/editor/formwindow.cpp')
-rw-r--r--kommander/editor/formwindow.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kommander/editor/formwindow.cpp b/kommander/editor/formwindow.cpp
index cbc64772..d81bc0c3 100644
--- a/kommander/editor/formwindow.cpp
+++ b/kommander/editor/formwindow.cpp
@@ -320,15 +320,15 @@ void FormWindow::insertWidget()
"properties as well as signals and slots to integrate custom widgets into "
"<i>TQt Designer</i>, and provide a pixmap which will be used to represent "
"the widget on the form.</p>")
- .tqarg(WidgetDatabase::toolTip(id)));
- TQToolTip::add(w, i18n("A %1 (custom widget)").tqarg(WidgetDatabase::toolTip(id)));
+ .arg(WidgetDatabase::toolTip(id)));
+ TQToolTip::add(w, i18n("A %1 (custom widget)").arg(WidgetDatabase::toolTip(id)));
}
else
{
TQString tt = WidgetDatabase::toolTip(id);
TQString wt = WidgetDatabase::whatsThis(id);
if (!wt.isEmpty() && !tt.isEmpty())
- TQWhatsThis::add(w, i18n("<b>A %1</b><p>%2</p>").tqarg(tt).tqarg(wt));
+ TQWhatsThis::add(w, i18n("<b>A %1</b><p>%2</p>").arg(tt).arg(wt));
}
TQString s = w->name();
@@ -387,13 +387,13 @@ void FormWindow::insertWidget()
else
setCursorToAll(CrossCursor, w);
- InsertCommand *cmd = new InsertCommand(i18n("Insert %1").tqarg(w->name()), this, w, r);
+ InsertCommand *cmd = new InsertCommand(i18n("Insert %1").arg(w->name()), this, w, r);
TQPtrList<Command> commands;
commands.append(mv);
commands.append(cmd);
- MacroCommand *mc = new MacroCommand(i18n("Insert %1").tqarg(w->name()), this, commands);
+ MacroCommand *mc = new MacroCommand(i18n("Insert %1").arg(w->name()), this, commands);
commandHistory()->addCommand(mc);
mc->execute();
}
@@ -404,7 +404,7 @@ void FormWindow::insertWidget()
else
setCursorToAll(CrossCursor, w);
- InsertCommand *cmd = new InsertCommand(i18n("Insert %1").tqarg(w->name()), this, w, r);
+ InsertCommand *cmd = new InsertCommand(i18n("Insert %1").arg(w->name()), this, w, r);
commandHistory()->addCommand(cmd);
cmd->execute();
}
@@ -428,15 +428,15 @@ void FormWindow::insertWidget(TQWidget *w, bool checkName)
"properties as well as signals and slots to integrate custom widgets into "
"<i>TQt Designer</i>, and provide a pixmap which will be used to represent "
"the widget on the form.</p>")
- .tqarg(WidgetDatabase::toolTip(id)));
- TQToolTip::add(w, i18n("A %1 (custom widget)").tqarg(WidgetDatabase::toolTip(id)));
+ .arg(WidgetDatabase::toolTip(id)));
+ TQToolTip::add(w, i18n("A %1 (custom widget)").arg(WidgetDatabase::toolTip(id)));
}
else
{
TQString tt = WidgetDatabase::toolTip(id);
TQString wt = WidgetDatabase::whatsThis(id);
if (!wt.isEmpty() && !tt.isEmpty())
- TQWhatsThis::add(w, i18n("<b>A %1</b><p>%2</p>").tqarg(tt).tqarg(wt));
+ TQWhatsThis::add(w, i18n("<b>A %1</b><p>%2</p>").arg(tt).arg(wt));
}
restoreCursors(w, this);
@@ -556,7 +556,7 @@ void FormWindow::handleMousePress(TQMouseEvent *e, TQWidget *w)
w = w->parentWidget();
if (e->button() == Qt::LeftButton)
- { // left button: store original tqgeometry and more as the widget might start moving
+ { // left button: store original geometry and more as the widget might start moving
widgetPressed = true;
widgetGeom = TQRect(w->pos(), w->size());
oldPressPos = w->mapFromGlobal(e->globalPos());
@@ -594,7 +594,7 @@ void FormWindow::handleMousePress(TQMouseEvent *e, TQWidget *w)
if (e->button() != Qt::LeftButton)
break;
saveBackground();
- mainWindow()->statusBar()->message(i18n("Connect '%1' with...").tqarg(w->name()));
+ mainWindow()->statusBar()->message(i18n("Connect '%1' with...").arg(w->name()));
connectStartPos = mapFromGlobal(e->globalPos());
currentConnectPos = mapFromGlobal(e->globalPos());
connectSender = TQT_TQOBJECT(designerWidget(TQT_TQOBJECT(w)));
@@ -767,7 +767,7 @@ void FormWindow::handleMouseMove(TQMouseEvent *e, TQWidget *w)
// finally move the selected widgets and show/update preview label
moveSelectedWidgets(x - p.x(), y - p.y());
- sizePreviewLabel->setText(TQString("%1/%2").tqarg(w->pos().x()).tqarg(w->pos().y()));
+ sizePreviewLabel->setText(TQString("%1/%2").arg(w->pos().x()).arg(w->pos().y()));
sizePreviewLabel->adjustSize();
TQRect lg(mapFromGlobal(e->globalPos()) + TQPoint(16, 16), sizePreviewLabel->size());
checkPreviewGeometry(lg);
@@ -803,7 +803,7 @@ void FormWindow::handleMouseMove(TQMouseEvent *e, TQWidget *w)
if (newReceiver && (isMainContainer(TQT_TQOBJECT(newReceiver))
|| insertedWidgets.find(newReceiver)) && !isCentralWidget(TQT_TQOBJECT(newReceiver)))
connectReceiver = connectableObject(TQT_TQOBJECT(newReceiver), TQT_TQOBJECT(connectReceiver));
- mainWindow()->statusBar()->message(i18n("Connect '%1' to '%2'").tqarg(connectSender->name()).
+ mainWindow()->statusBar()->message(i18n("Connect '%1' to '%2'").arg(connectSender->name()).
arg(connectReceiver->name()));
tqApp->processEvents();
if (drawRecRect)
@@ -871,7 +871,7 @@ void FormWindow::handleMouseRelease(TQMouseEvent * e, TQWidget * w)
"In order to insert the widget, the tqlayout of '%1'\n"
"must first be broken.\n"
"Break the tqlayout or cancel the operation?").
- tqarg(wa->name()).tqarg(wa->name()), i18n("Inserting Widget"),
+ arg(wa->name()).arg(wa->name()), i18n("Inserting Widget"),
i18n("&Break Layout"), KStdGuiItem::cancel()) == KMessageBox::No)
goto make_move_command; // cancel
breakLayout(wa);
@@ -1239,7 +1239,7 @@ void FormWindow::continueRectDraw(const TQPoint & p, const TQPoint & global, TQW
if (currRect == r)
{
TQString t("%1/%2");
- t = t.tqarg(r.width() - 1).tqarg(r.height() - 1);
+ t = t.arg(r.width() - 1).arg(r.height() - 1);
drawSizePreview(pos, t);
return;
}
@@ -1253,7 +1253,7 @@ void FormWindow::continueRectDraw(const TQPoint & p, const TQPoint & global, TQW
if (t == Insert)
{
TQString t("%1/%2");
- t = t.tqarg(r.width() - 1).tqarg(r.height() - 1);
+ t = t.arg(r.width() - 1).arg(r.height() - 1);
drawSizePreview(pos, t);
}
unclippedPainter->setClipRegion(TQRegion(rect()).subtract(TQRect(sizePreviewPos,
@@ -1431,13 +1431,13 @@ void FormWindow::editAdjustSize()
TQWidgetList widgets = selectedWidgets();
if (widgets.isEmpty())
{
- TQRect oldr = tqgeometry();
+ TQRect oldr = geometry();
mainContainer()->adjustSize();
resize(mainContainer()->size());
// check whether our own size constraint hit us
if (size() != mainContainer()->size())
mainContainer()->resize(size());
- TQRect nr = tqgeometry();
+ TQRect nr = geometry();
if (oldr != nr)
{
ResizeCommand *cmd = new ResizeCommand(i18n("Adjust Size"), this, this, oldr, nr);
@@ -1450,9 +1450,9 @@ void FormWindow::editAdjustSize()
if (w->parentWidget()
&& WidgetFactory::layoutType(w->parentWidget()) != WidgetFactory::NoLayout)
continue;
- TQRect oldr = w->tqgeometry();
+ TQRect oldr = w->geometry();
w->adjustSize();
- TQRect nr = w->tqgeometry();
+ TQRect nr = w->geometry();
if (oldr != nr)
commands.append(new ResizeCommand(i18n("Adjust Size"), this, w, oldr, nr));
}
@@ -1844,7 +1844,7 @@ void FormWindow::checkAccels()
{
ok = false;
if (KMessageBox::questionYesNo(mainWindow(),
- i18n("Accelerator '%1' is used %2 times.").tqarg(it.key().upper()).tqarg((*it).count()),
+ i18n("Accelerator '%1' is used %2 times.").arg(it.key().upper()).arg((*it).count()),
i18n("Check Accelerators"), i18n("&Select"), KStdGuiItem::cancel()) == KMessageBox::Yes)
{
clearSelection(false);